package contapalavras;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.InputStreamReader;
import java.io.Reader;

public class Main {

    public static void main(String[] args) throws FileNotFoundException {
        if (args.length != 3) {
            System.out.println("Número de parâmetros inválidos.");
            System.out.println("Mode de uso:");
            System.out.println("  java " + Main.class.getCanonicalName() + " impl nome-arquivo quantidade");
            System.out.println("onde");
            System.out.println("  impl         implementação a ser usada");
            System.out.println("               use array para a implementação que usa ArrayList");
            System.out.println("               use map para a implementação que usa HashMap");
            System.out.println("  nome-arquivo nome do arquivo com o texto cujo a palavras serão contadas");
            System.out.println("               use - para ler da entrada padrão");
            System.out.println("  quantidade   quantidade de palavras com mais frequencia que serão exibidas.");
            System.exit(1);
        }

        String impl = args[0];
        String arquivo = args[1];
        int quantidade = Integer.parseInt(args[2]);

        Contagem contagem = null;
        switch (impl) {
            case "array":
                contagem = new ContagemArrayList();
                break;
            case "map":
                contagem = new ContagemHashMap();
                break;
            default:
                System.out.println("Argumento impl inválido: " + impl);
                System.exit(1);
        }

        Reader entrada;
        if (arquivo.equals("-")) {
            entrada = new InputStreamReader(System.in);
        } else {
            entrada = new FileReader(arquivo);
        }

        ContaPalavras contaPalavras = new ContaPalavras(contagem);
        contaPalavras.adicionaPalavras(entrada);
        contaPalavras.exibeMaisFrequentes(System.out, quantidade);
    }
}
